using System.Data;

namespace EnterprisePatterns.DataAccess
{
    public class DatabaseConnection : IDatabaseConnection
    {
        private bool disposed;
        private IDbConnection underlyingConnection;


        public DatabaseConnection(IDbConnectionFactory dbConnectionFactory)
        {
            underlyingConnection = dbConnectionFactory.Create();
            underlyingConnection.Open();
        }

        ~DatabaseConnection()
        {
            Dispose(false);
        }

        public void Dispose()
        {
            Dispose(true);
        }

        private void Dispose(bool disposing)
        {
            if (! disposed)
            {
                if (disposing)
                {
                    underlyingConnection.Dispose();
                }
                disposed = true;
            }
        }

        public IDbCommand CreateCommandForDynamicSql(string sqlStatement)
        {
            IDbCommand command = underlyingConnection.CreateCommand();
            command.CommandText = sqlStatement;
            command.CommandType = CommandType.Text;
            return command;
        }
    }
}