using System.Configuration;
using System.Data;
using System.Data.Common;
using EnterprisePatterns.DataAccess;

namespace EnterprisePatterns.DataAccess
{
    public class DbConnectionFactory : IDbConnectionFactory
    {
        private string connectionString;
        private DbProviderFactory providerFactory;
        private const string ConnectionSettingsKey = "activeConnection";


        public DbConnectionFactory():this(ConfigurationManager.ConnectionStrings[ConfigurationManager.AppSettings[ConnectionSettingsKey]])
        {
        }

        public DbConnectionFactory(ConnectionStringSettings connectionSettings)
        {
            providerFactory = DbProviderFactories.GetFactory(connectionSettings.ProviderName);
            connectionString = connectionSettings.ConnectionString;
        }

        public IDbConnection Create()
        {
            IDbConnection connection = providerFactory.CreateConnection();
            connection.ConnectionString = connectionString;
            return connection;
        }
    }
}