using System;
using System.Collections.Generic;
using System.Data;
using EnterprisePatterns.Domain;

namespace EnterprisePatterns.DataAccess
{
    public class EmployeeMapper : IEmployeeMapper
    {
        private IDatabaseGateway gateway;


        public EmployeeMapper(IDatabaseGateway gateway)
        {
            this.gateway = gateway;
        }

        public IList<IEmployee> FindAll()
        {
            DataTable results = gateway.ExecuteSqlForDataTable(Queries.All);
            IList<IEmployee> employees = new List<IEmployee>();

            foreach (DataRow row in results.Rows)
            {
                employees.Add(MapFrom(row));
            }

            return employees;
        }

        private IEmployee MapFrom(DataRow row)
        {
            return
                new Employee(Convert.ToInt32(row[TableDefinitions.Employees.ID.ColumnName]), row[TableDefinitions.Employees.LastName.ColumnName].ToString(),
                             row[TableDefinitions.Employees.FirstName.ColumnName].ToString(), row[TableDefinitions.Employees.Title.ColumnName].ToString(),
                             Convert.ToDateTime(row[TableDefinitions.Employees.BirthDate.ColumnName]),
                             Convert.ToDateTime(row[TableDefinitions.Employees.HireDate.ColumnName]));
        }

        public class Queries
        {
            public static readonly string All = string.Format("SELECT * FROM {0}", TableDefinitions.Employees.TableName);
        }
    }
}