using System.Data;
using EnterprisePatterns.DataAccess;
using NUnit.Framework;
using Rhino.Mocks;

namespace EnterprisePatterns.DataAccess.Test
{
    [TestFixture]
    public class DatabaseConnectionTest
    {
        private const string SELECT_SQL = "SELECT * FROM Customers";
        private MockRepository mockery;        
        private IDbConnection mockDbConnection;
        private IDbConnectionFactory mockDbConnectionFactory;


        [SetUp]
        public void Setup()
        {
            mockery = new MockRepository();
            mockDbConnectionFactory = mockery.CreateMock<IDbConnectionFactory>();
            mockDbConnection = mockery.CreateMock<IDbConnection>();            
            Expect.Call(mockDbConnectionFactory.Create()).Return(mockDbConnection);
            mockDbConnection.Open();
        }

        [TearDown]
        public void TearDown()
        {
            mockery.VerifyAll();
        }

        [Test]
        public void ShouldRetrieveAndOpenUnderlyingConnection()
        {            
            mockery.ReplayAll();
            IDatabaseConnection connection = CreateConnection();            
        }

        private IDatabaseConnection CreateConnection()
        {
            return new DatabaseConnection(mockDbConnectionFactory);
        }

        [Test]
        public void ShouldDisposeUnderlyingConnection()
        {
            mockDbConnection.Dispose();
            mockery.ReplayAll();
            using (IDatabaseConnection connection = CreateConnection())
            {
                
            }
        }


        [Test]
        public void ShouldCreateCommandForSqlStatement()
        {
            IDbCommand mockCommand = mockery.CreateMock<IDbCommand>();
            Expect.Call(mockDbConnection.CreateCommand()).Return(mockCommand);
            mockCommand.CommandText = SELECT_SQL;
            mockCommand.CommandType = CommandType.Text;
            mockery.ReplayAll();

            IDatabaseConnection connection = CreateConnection();
            IDbCommand command = connection.CreateCommandForSqlStatement(SELECT_SQL);
            Assert.AreEqual(mockCommand,command);
        }
    }
}