using System.Data;
using EnterprisePatterns.DataAccess;
using NUnit.Framework;
using Rhino.Mocks;

namespace EnterprisePatterns.DataAccess.Test
{
    [TestFixture]
    public class DatabaseGatewayTest
    {
        private const string SQL_STATEMENT = "SELECT * FROM Blah";
        private MockRepository mockery;

        [TestFixtureSetUp]
        public void FixtureSetUp()
        {
                
        }
        
        [SetUp]
        public void Setup()
        {
            mockery = new MockRepository();
        }

        [TearDown]
        public void TearDown()
        {
            mockery.VerifyAll();
        }

        [Test]
        public void ShouldExecuteSqlForDataTable()
        {
            IDbCommand mockCommand = mockery.CreateMock<IDbCommand>();
            IDataReader mockReader = mockery.DynamicMock<IDataReader>();
            IDatabaseConnection mockConnection = mockery.CreateMock<IDatabaseConnection>();
            IConnectionFactory mockConnectionFactory = mockery.CreateMock<IConnectionFactory>();

            using (mockery.Ordered())
            {
                Expect.Call(mockConnectionFactory.Create()).Return(mockConnection);
                Expect.Call(mockConnection.CreateCommandForSqlStatement(SQL_STATEMENT)).Return(mockCommand);
                Expect.Call(mockCommand.ExecuteReader()).Return(mockReader);                
                mockReader.Dispose();
                mockConnection.Dispose();
            }

            mockery.ReplayAll();

            IDatabaseGateway gateway = new DatabaseGateway(mockConnectionFactory);

            DataTable results = gateway.ExecuteSqlForDataTable(SQL_STATEMENT);
            Assert.IsNotNull(results);
        }

    }
}