using System.Data;
using System.Data.SqlClient;
using EnterprisePatterns.DataAccess;
using NUnit.Framework;
using Rhino.Mocks;

namespace EnterprisePatterns.DataAccess.Test
{
    [TestFixture]
    public class DbConnectionFactoryTest
    {
        private const string SQL_PROVIDER_NAME = "System.Data.SqlClient";
        private const string DUMMY_CONNECTION_STRING = "data source=(local);Integrated Security=SSPI;Initial Catalog=NW";
        private MockRepository mockery;

        [SetUp]
        public void Setup()
        {
            mockery = new MockRepository();
        }

        [TearDown]
        public void TearDown()
        {
            mockery.VerifyAll();
        }

        [Test]
        public void ShouldCreateConnectionFromConfiguration()
        {
            IDbConfiguration mockConfiguration = mockery.CreateMock<IDbConfiguration>();
            Expect.Call(mockConfiguration.ProviderName).Return(SQL_PROVIDER_NAME);
            Expect.Call(mockConfiguration.ConnectionString).Return(DUMMY_CONNECTION_STRING);
            
            mockery.ReplayAll();

            IDbConnectionFactory connectionFactory = new DbConnectionFactory(mockConfiguration);
            IDbConnection connection = connectionFactory.Create();
            Assert.IsInstanceOfType(typeof(SqlConnection),connection);
            Assert.AreEqual(DUMMY_CONNECTION_STRING,connection.ConnectionString);
        }
    }
}